@@ -124,7 +124,7 @@ pmvtAlgo <- function(dim, x, ...) {
 }
 
 
-ptCopula <- function(u, copula, algorithm = NULL, ...)
+ptCopula <- function(u, copula, algorithm = NULL, keepAttr=FALSE, ...)
 {
   dim <- copula@dimension
   i.lower <- rep.int(-Inf, dim)
@@ -138,7 +138,8 @@ ptCopula <- function(u, copula, algorithm = NULL, ...)
       else { # algorithm depending on 'x' ..
           if(is.null(algorithm))
               algorithm <- pmvtAlgo(dim, x=x, ...)
-          pmvt(lower = i.lower, upper = x, sigma=sigma, df=df, algorithm=algorithm, ...)
+          pmvt(lower = i.lower, upper = x, sigma=sigma, df=df,
+               algorithm=algorithm, keepAttr=keepAttr, ...)
       })
 }
 
@@ -159,17 +160,9 @@ dtCopula <- function(u, copula, log = FALSE, ...) {
 }
 
 
-printTCopula <- function(x, ...) {
-  printCopula(x, ...)
-  if (x@dimension > 2) cat("dispstr: ", x@dispstr, "\n")
-  ## redundant now with := in params
-  ## if (x@df.fixed) cat("df is fixed at", getdf(x), "\n")
-  invisible(x)
-}
-
 ## as long we think we need print.copula(), we also need this:
-print.tCopula <- printTCopula
-setMethod("show", signature("tCopula"), function(object) printTCopula(object))
+print.tCopula <- printEllipCopula
+setMethod("show", signature("tCopula"), function(object) printEllipCopula(object))
 
 
 lambdaTCopula <- function(copula)
